Coverage for /media/ldata/code/tendril/tendril/entityhub/transforms.py: 0%

# Coverage for /media/ldata/code/tendril/tendril/entityhub/transforms.py : 0%

## 31 statements 0 run 31 missing 0 excluded

Hot-keys on this page

r m x p toggle line displays

j k next/prev highlighted chunk

0 (zero) top of page

1 (one) first highlighted chunk

1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 | # Copyright (C) 2015 Chintalagiri Shashank # # This file is part of Tendril. # # This program is free software: you can redistribute it and/or modify # it under the terms of the GNU Affero General Public License as published by # the Free Software Foundation, either version 3 of the License, or # (at your option) any later version. # # This program is distributed in the hope that it will be useful, # but WITHOUT ANY WARRANTY; without even the implied warranty of # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the # GNU Affero General Public License for more details. # # You should have received a copy of the GNU Affero General Public License # along with this program. If not, see <http://www.gnu.org/licenses/>. """ EntityHub Transforms Module documentation (:mod:`entityhub.transforms`) ======================================================================= """ import csv class TransformFile(object): def __init__(self, tfpath): self._transform = {} self._ideal = {} self._status = {} with open(tfpath) as f: rdr = csv.reader(f) for row in rdr: self._transform[row[0].strip()] = row[1].strip() self._ideal[row[0].strip()] = row[2].strip() try: self._status[row[0].strip()] = row[3].strip() except IndexError: self._status[row[0].strip()] = '' def get_canonical_repr(self, contextual): return self._transform[contextual.strip()] def get_ideal_repr(self, contextual): return self._ideal[contextual.strip()] def get_status(self, contextual): return self._status[contextual.strip()] def get_contextual_repr(self, canonical): for (k, v) in self._transform.iteritems(): if v == canonical.strip(): return k return None def has_contextual_repr(self, contextual): if contextual.strip() in self._transform.keys(): return True else: return False